{% extends "styled.html" %} {% block style %} {{super()}} body { max-width: 1440px; } td.title { word-break: break-all; } td.time { color: #555; text-align: right; white-space: nowrap; } table { margin-bottom: 30px; } .date { color: #555; font-size: 12pt; padding-bottom: 15px; font-weight: bold; text-align: left; } .pagination-link { color: #555; font-weight: bold; margn-bottom: 15px; text-decoration: none; } {% endblock %} {% block content %}

# Browsing history

{{curr_date.strftime("%a, %d %B %Y")}}
{% for url, title, time, host in history %}
{{title}} {{host}} | {{time.strftime("%X")}}
{% endfor %}

Previous {% if today >= next_date %} Next {% endif %} {% endblock %}